package com.novapp.nova_alarm_plugin;

import android.app.Activity;
import android.content.Intent;
import android.media.MediaPlayer;

import androidx.annotation.NonNull;

import com.novapp.nova_alarm_plugin.alarm.AlarmUtils;
import com.novapp.nova_alarm_plugin.calendar.CalendarReminderUtils;
import com.novapp.nova_alarm_plugin.utils.ClockPluginConstant;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static com.novapp.nova_alarm_plugin.utils.ClockPluginConstant.*;

/**
 * NovaAlarmPlugin
 */
public class NovaAlarmPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private static Activity appContext;


    private MediaPlayer player = new MediaPlayer();


    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "nova_alarm_plugin");
        channel.setMethodCallHandler(new NovaAlarmPlugin());
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        appContext = registrar.activity();
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "nova_alarm_plugin");
        channel.setMethodCallHandler(new NovaAlarmPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

        switch (call.method) {
            case initClockService:



                initClockService(call);
                result.success(true);
                break;
            case requestCalendarPermission:
                CalendarReminderUtils.checkCalendarPermission(appContext);
                break;
            case insertCalenderEvent:
                CalendarReminderUtils.addCalendarEvent(appContext, call, result);
                break;
            case deleteCalendarEvent:
                CalendarReminderUtils.deleteCalendarEvent(appContext, call, result);
                break;
            case showAndroidNotification:
                startClockNotification(call);
                break;
            case setClock:
                AlarmUtils.addClock(appContext,call,result);
                break;
            case cancelAllClock:
                AlarmUtils.closeClock(appContext);
                break;
            default:
                result.notImplemented();
                break;
        }

    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        appContext = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }

    private void initClockService(MethodCall call) {

        Intent initIntent = new Intent(appContext, KeepAliveService.class);
        appContext.startService(initIntent);


        Intent intent = new Intent(appContext, KeepAliveService.class);


        String title = call.argument("title");
        String content = call.argument("content");
        intent.putExtra("type", initService);
        intent.putExtra("title",title);
        intent.putExtra("content",content);
        appContext.startService(intent);
    }

    private void startClockNotification(@NonNull final MethodCall call) {
        String title = call.argument("title");
        String content = call.argument("content");
        int notifyId = 0;
        if (call.argument("nofityId") != null){
            notifyId = call.argument("nofityId");
        }
        Intent intent = new Intent(appContext, KeepAliveService.class);
        intent.putExtra("type",notification);
        intent.putExtra("title", title);
        intent.putExtra("content", content);
        intent.putExtra("notifyId", notifyId);
        appContext.startService(intent);
    }
}
