package com.novapp.nova_alarm_plugin.alarm;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.provider.AlarmClock;

import androidx.core.app.ActivityCompat;

import java.util.Calendar;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

import static androidx.core.content.ContextCompat.checkSelfPermission;

public class AlarmUtils {



    public static void addClock(Activity activity, MethodCall call, MethodChannel.Result result) {
        String reminderTime = call.argument("time");
        Calendar mCalendar = Calendar.getInstance();
        mCalendar.setTimeInMillis(Long.parseLong(reminderTime));//设置开始时间
        String content = call.argument("content");
        int hour = mCalendar.get(Calendar.HOUR_OF_DAY);
        int minute = mCalendar.get(Calendar.MINUTE);
        if (checkAlarmPermission(activity)){
            setAlarmClock(activity, content, hour, minute);
            result.success(true);
        }else {
            result.error("-1","no permission","please request setAlarmPermission");
        }
    }

    public static void closeClock(Activity activity){
        Intent intent = new Intent(AlarmClock.ACTION_DISMISS_ALARM);
        activity.startActivity(intent);
    }


    private static void setAlarmClock(Context context, String message, int hour, int minutes) {
        //action为AlarmClock.ACTION_SET_ALARM
        Intent intent = new Intent(AlarmClock.ACTION_SET_ALARM)
                //闹钟的小时
                .putExtra(AlarmClock.EXTRA_HOUR, hour)
                //闹钟的分钟
                .putExtra(AlarmClock.EXTRA_MINUTES, minutes)
                //响铃时提示的信息
                .putExtra(AlarmClock.EXTRA_MESSAGE, message);
        //如果为true，则调用startActivity()不会进入手机的闹钟设置界面
        intent.putExtra(AlarmClock.EXTRA_SKIP_UI, true);
        if (Build.VERSION.SDK_INT >= 19) {
            //用于指定该闹铃触发时是否振动
            intent.putExtra(AlarmClock.EXTRA_VIBRATE, true);
        }
        if (intent.resolveActivity(context.getPackageManager()) != null) {
            context.startActivity(intent);
        }
    }


    private static boolean checkAlarmPermission(Activity activity) {
        int REQUEST_CODE_CALL_PHONE = 2001;
        if (checkSelfPermission(activity, Manifest.permission.SET_ALARM) != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(activity,
                    new String[]{Manifest.permission.SET_ALARM}, REQUEST_CODE_CALL_PHONE);
            return false;
        }
        return true;
    }
}
